==> 4.4.3.tar.gz: terraform-provider-decort/samples/cloudapi/data_account_computes_list/main.tf <==
/*
Пример использования
Получение списка computes, используемых аккаунтом

*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
}
*/

provider "decort" {
  authenticator = "oauth2"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_account_computes_list" "acl" {
  #id аккаунта
  #обязательный параметр
  #тип - число
  account_id = 1111

  #фильтр по id compute
  #опциональный параметр
  #тип - число
  #compute_id = 100

  #фильтр по имени compute
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #rg_name = "test"

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - число
  #rg_id = 100

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "STARTED"

  #фильтр по ip address
  #опциональный параметр
  #тип - строка
  #ip_address = "1.1.1.1.1"

  #фильтр по имени внешней сети
  #опциональный параметр
  #тип - строка
  #extnet_name = "test"

  #фильтр по id внешней сети
  #опциональный параметр
  #тип - число
  #extnet_id = 100

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 1
}

output "test" {
  value = data.decort_account_computes_list.acl
}

==> 4.5.0.tar.gz: terraform-provider-decort/samples/cloudapi/data_account_computes_list/main.tf <==
/*
Пример использования
Получение списка computes, используемых аккаунтом

*/
#Расскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    decort = {
      version = "<VERSION>"
      source  = "basis/decort/decort"
    }
  }
}
*/

provider "decort" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

data "decort_account_computes_list" "acl" {
  #id аккаунта
  #обязательный параметр
  #тип - число
  account_id = 1111

  #фильтр по id compute
  #опциональный параметр
  #тип - число
  #compute_id = 100

  #фильтр по имени compute
  #опциональный параметр
  #тип - строка
  #name = "test"

  #фильтр по имени ресурсной группы
  #опциональный параметр
  #тип - строка
  #rg_name = "test"

  #фильтр по id ресурсной группы
  #опциональный параметр
  #тип - число
  #rg_id = 100

  #фильтр по техническому статусу
  #опциональный параметр
  #тип - строка
  #tech_status = "STARTED"

  #фильтр по ip address
  #опциональный параметр
  #тип - строка
  #ip_address = "1.1.1.1.1"

  #фильтр по имени внешней сети
  #опциональный параметр
  #тип - строка
  #extnet_name = "test"

  #фильтр по id внешней сети
  #опциональный параметр
  #тип - число
  #extnet_id = 100

  #номер страницы для отображения
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #page = 1

  #размер страницы
  #опциональный параметр
  #тип - число
  #если не задан - выводятся все доступные данные
  #size = 1
}

output "test" {
  value = data.decort_account_computes_list.acl
}
